League of Legends - Play For Free

- > “One of the most refreshing strategy games in years.”

  > – GameTrailers

- > “Tense and completely riveting to play.”

  > – Eurogamer

- > “Our favorite Free Game”

  > – PC Gamer

- > “One hell of a great multiplayer game.”

  > – Gamespy

Username:
Your username is used to login to the game.
Password:
Confirm Password:
Email Address:
Date of Birth: - -
Region:
North America (change)

- Please select the region that is closest to you.
- North America
- EU West
- EU Nordic & East
- Brasil
- Turkey
- Russia
- Latin America North
- Latin America South
- Oceania

I agree to the Terms of Use, EULA and Privacy Policy
Sign me up to receive the League of Legends Newsletter and other game-related or promotional emails from Riot Games and/or its partners. I understand I can unsubscribe at any time.

Already have an account? Download the Game

# Error

OK